[![GitHub Release](https://img.shields.io/github/release/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=blue)](https://github.com/Vaskivskyi/aiochroma/releases) [![License](https://img.shields.io/github/license/Vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)](LICENSE)<br/>
![Downloads](https://img.shields.io/pypi/dm/aiochroma?style=for-the-badge&color=blue) ![Commit activity](https://img.shields.io/github/commit-activity/m/vaskivskyi/aiochroma.svg?style=for-the-badge&color=yellow)<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-blue.png" alt="Buy Me A Coffee" style="height: 28px !important;" align="right" /></a>

## AIOChroma

**AIOChroma** is an API wrapper for communication with Razer Chroma devices.

Up till now, it is mostly used for the [custom Chroma integration for Home Assistant](https://github.com/Vaskivskyi/ha-chroma). But you are welcome to use it for your purposes, as well as suggest new features which you would like to use.

## Installation

Installation of the latest release is available from PyPI:

```
pip install aiochroma
```

## Usage

This section is still under development.

## Support the development

This library is a free-time project. If you like it, you can support me by buying a coffee.

<a href="https://www.buymeacoffee.com/vaskivskyi" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-blue.png" alt="Buy Me A Coffee" style="height: 60px !important;"></a>
